@@ -146,12 +146,14 @@ class DataMediator:
         dataframe attached to this instance, into experimental
         & control dataframes.
         """
+        import logging
+
         missingIDs = []
         for ID in IDs:
             if ID not in self.dataframe.index:
                 missingIDs.append(ID)
-        if self.verbose:
-            print(f"samples missing from feature data: {missingIDs}")
+        if len(missingIDs) >= 1:
+            logging.warning(f"samples missing from feature data: {missingIDs}")
         return self.dataframe.loc[[ID for ID in IDs if ID in self.dataframe.index]]
 
     def __balance(
