@@ -1,10 +1,7 @@
 """
 Experiment trackers for machine learning pipelines.
 """
-import random
-from inspect import getsourcefile
 import os
-import shutil
 from abc import ABC, abstractmethod
 
 import neptune.new as neptune
@@ -13,12 +10,14 @@ from neptune.new.types import File
 import wandb
 from io import BytesIO, StringIO
 import pandas as pd
+from plotly.io import to_html
 
 # typing
 from numpy import ndarray
 from pandas import DataFrame
 from typing import Union, List
 from matplotlib.figure import Figure
+from plotly.graph_objs._figure import Figure as PlotlyFigure
 
 # TODO: implementation-specific documentation
 
@@ -120,15 +119,18 @@ class NeptuneExperimentTracker(ExperimentTracker):
 
         for (key, value) in valueMap.items():
             if isinstance(value, Figure):
-                fileHandle = BytesIO()
+                fileHandle, previewHandle = BytesIO(), BytesIO()
                 value.savefig(fileHandle, format="svg", bbox_inches="tight")
                 loggable[f"{path}/{key}"].upload(
                     File.from_stream(fileHandle, extension="svg")
                 )
+                value.savefig(previewHandle, format="png", bbox_inches="tight")
                 loggable[f"{path}/{key} preview"].upload(
-                    File.as_image(
-                        value.savefig(fileHandle, format="png", bbox_inches="tight")
-                    )
+                    File.from_stream(previewHandle, extension="png")
+                )
+            elif isinstance(value, PlotlyFigure):
+                loggable[f"{path}/{key}"].upload(
+                    File.from_content(to_html(value), extension="html")
                 )
             elif isinstance(value, DataFrame):
                 tableStream = BytesIO()
