@@ -173,9 +173,7 @@ class BayesianOptimizer:
         self.bestParametersByRegressor = dict()
         bestParameters = {"regressor": None, "score": float("inf"), "parameters": None}
         loadedObjective = partial(
-            use_named_args(hyperparameterSpaces[model.__class__.__name__])(
-                objectiveToMinimize
-            ),
+            use_named_args(hyperparameterSpaces)(objectiveToMinimize),
             **{
                 "model": model,
                 "trainingData": trainingData,
